@@ -1,4 +1,5 @@
 # Copyright (c) Open-MMLab. All rights reserved.
+import ast
 import os.path as osp
 import shutil
 import sys
@@ -14,6 +15,7 @@ from .path import check_file_exist
 
 BASE_KEY = '_base_'
 DELETE_KEY = '_delete_'
+RESERVED_KEYS = ['filename', 'text', 'pretty_text']
 
 
 class ConfigDict(Dict):
@@ -53,7 +55,7 @@ def add_args(parser, cfg, prefix=''):
     return parser
 
 
-class Config(object):
+class Config:
     """A facility for config and config files.
 
     It supports common file formats as configs: python/json/yaml. The interface
@@ -79,6 +81,16 @@ class Config(object):
 
     """
 
+    @staticmethod
+    def _validate_py_syntax(filename):
+        with open(filename) as f:
+            content = f.read()
+        try:
+            ast.parse(content)
+        except SyntaxError:
+            raise SyntaxError('There are syntax errors in config '
+                              f'file {filename}')
+
     @staticmethod
     def _file2dict(filename):
         filename = osp.abspath(osp.expanduser(filename))
@@ -92,6 +104,7 @@ class Config(object):
                                 osp.join(temp_config_dir, temp_config_name))
                 temp_module_name = osp.splitext(temp_config_name)[0]
                 sys.path.insert(0, temp_config_dir)
+                Config._validate_py_syntax(filename)
                 mod = import_module(temp_module_name)
                 sys.path.pop(0)
                 cfg_dict = {
@@ -184,6 +197,9 @@ class Config(object):
         elif not isinstance(cfg_dict, dict):
             raise TypeError('cfg_dict must be a dict, but '
                             f'got {type(cfg_dict)}')
+        for key in cfg_dict:
+            if key in RESERVED_KEYS:
+                raise KeyError(f'{key} is reserved for config file')
 
         super(Config, self).__setattr__('_cfg_dict', ConfigDict(cfg_dict))
         super(Config, self).__setattr__('_filename', filename)
